<?php

require_once 'crypto/password.php';
require_once 'db/db-executor.php';
require_once 'auth/token.php';

function authenticateToken(string $token): string {
    $query = 'SELECT account_id FROM token WHERE token=:token LIMIT 1';
    $params = [
        'token' => $token
    ];

    $res = execSelect($query, $params);
    if (empty($res)) {
        header('Location: /login', true, 303);
        exit();
    }
    return $res[0]['account_id'];
}

function authenticateCredentials(string $username, string $password): string {
    $query = 'SELECT a.account_id, a.password, t.token FROM account a LEFT JOIN token t on a.account_id = t.account_id
              WHERE a.username = :username LIMIT 1';
    $params = [
        'username' => $username
    ];

    $res = execSelect($query, $params);
    if (empty($res)) {
        return "";
    }

    $creds = $res[0];
    if (!verifyPassword($password, $creds['password'])) {
        return "";
    }
    if (!$creds['token']) {
        $creds['token'] = getToken($creds['account_id']);
    }

    return $creds['token'];
}