<?php

require_once 'db/db-executor.php';
require_once 'auth/authenticator.php';
require_once 'util/album-finder.php'; 

$errMsg = '';


try {
    switch ($_SERVER['REQUEST_METHOD']) {
        case 'GET':
            // Get the full URL including additional parameters
            $fullUrl = $_SERVER['REQUEST_URI'];

            // Split the URL to separate the base route and parameters
            $parts = explode('?', $fullUrl);
            
            // Extract the base route (e.g., /album/fetch/)
            $baseRoute = $parts[0];
            
            // Extract and parse the query parameters
            $queryString = isset($parts[1]) ? $parts[1] : '';
            parse_str($queryString, $queryParams);

            // Extract individual parameters
            $csrfToken = $queryParams['csrf_token']; 
            $searchQuery = $queryParams['q']; 

            // Prevent CSRF Attacks
            if(!authenticateToken($csrfToken)) {
                http_response_code(401);
                exit;
            }

            // Limit and Page
            $limit = $queryParams['l'];
            $currentPage = $queryParams['p'];

            // Prevent injection on order by
            $orders = array("name","year");
            $key=array_search($_GET['sort'],$orders);
            $order=$orders[$key];
            $directions = array("ASC","DESC");
            $key=array_search($_GET['order'],$directions);
            $direction=$directions[$key];
            
            // Filter by creator
            $creatorCondition = $queryParams['creator'];

            if ($queryParams['creator'] != 'all') {
                $query = 'SELECT album.*, account.username as username FROM album INNER JOIN account ON album.owner_account_id = account.account_id WHERE (album.name LIKE :searchQuery OR account.username LIKE :searchQuery) AND owner_account_id = :creator ORDER BY '.$order.' '.$direction.' LIMIT :limit OFFSET :offset';
                $params = [
                    'searchQuery' => '%'.$searchQuery.'%',
                    'creator' => $creatorCondition,
                    'limit' => $limit,
                    'offset' => ($currentPage-1)*$limit,
                ];
            } else {
                $query = 'SELECT album.*, account.username as username FROM album INNER JOIN account ON album.owner_account_id = account.account_id WHERE (album.name LIKE :searchQuery OR account.username LIKE :searchQuery) ORDER BY '.$order.' '.$direction.' LIMIT :limit OFFSET :offset';
                $params = [
                    'searchQuery' => '%'.$searchQuery.'%',
                    'limit' => $limit,
                    'offset' => ($currentPage-1)*$limit,
                ];
            } 

            $albumRes = execSelect($query, $params);

            // Get the image src for each album
            foreach ($albumRes as &$album) {
                $album['album_cover_filename'] = getAlbumImageByID($album['album_id']);
            }

            $res = [
                'albums' => $albumRes,
            ];
            header('Content-Type: application/json');
            http_response_code(200);
            echo json_encode($res);
            exit;

            break;
        default:
            http_response_code(401);
            exit;
    }
} catch (Exception $e) {
    http_response_code($e->getCode());
    exit;
}
