<?php

require_once 'db/db-executor.php';
require_once 'auth/authenticator.php';
require_once 'util/album-finder.php'; 

$errMsg = '';


try {
    switch ($_SERVER['REQUEST_METHOD']) {
        case 'GET':
            // Get the full URL including additional parameters
            $fullUrl = $_SERVER['REQUEST_URI'];
            
            // Split the URL to separate the base route and parameters
            $parts = explode('?', $fullUrl);

            // Extract the base route (e.g., /album/fetch/)
            $baseRoute = $parts[0];
            
            // Extract and parse the query parameters
            $queryString = isset($parts[1]) ? $parts[1] : '';
            parse_str($queryString, $queryParams);

            // Extract individual parameters
            $csrfToken = $queryParams['csrf_token']; 
            $searchQuery = $queryParams['q']; 
            // $sortBy = $queryParams['sort'];
            // $order = $queryParams['order'];
            
            // Prevent CSRF Attacks
            if (!authenticateToken($csrfToken)) {
                http_response_code(401);
                exit;
            }

            // Limit and Page
            $limit = $queryParams['l'];
            $currentPage = $queryParams['p'];

            // Prevent injection on order by
            $orders = array("title","year");
            $key=array_search($_GET['sort'],$orders);
            $order=$orders[$key];
            $directions = array("ASC","DESC");
            $key=array_search($_GET['order'],$directions);
            $direction=$directions[$key];

            //Filter by genre or creator
            $genreCondition = $queryParams['genre'];
            $creatorCondition = $queryParams['creator'];

            if ($queryParams['genre'] != 'all' && $queryParams['creator'] == 'all') {
                $query = 'SELECT *, username FROM music INNER JOIN account ON music.owner_account_id = account.account_id WHERE (music.title LIKE :searchQuery OR music.genre LIKE :searchQuery) AND genre = :genreCondition ORDER BY '.$order.' '.$direction.' LIMIT :limit OFFSET :offset';
                $params = [
                    'searchQuery' => '%'.$searchQuery.'%',
                    'genreCondition' => $genreCondition,
                    'limit' => $limit,
                    'offset' => ($currentPage-1)*$limit,
                ];
            }

            if ($queryParams['genre'] == 'all' && $queryParams['creator'] != 'all') {
                $query = 'SELECT *, username FROM music INNER JOIN account ON music.owner_account_id = account.account_id WHERE (music.title LIKE :searchQuery OR music.genre LIKE :searchQuery) AND  owner_account_id = :creatorCondition ORDER BY '.$order.' '.$direction.' LIMIT :limit OFFSET :offset';
                $params = [
                    'searchQuery' => '%'.$searchQuery.'%',
                    'creatorCondition' => $creatorCondition,
                    'limit' => $limit,
                    'offset' => ($currentPage-1)*$limit,
                ];
            }

            if ($queryParams['genre'] != 'all' && $queryParams['creator'] != 'all') {
                $query = 'SELECT *, username FROM music INNER JOIN account ON music.owner_account_id = account.account_id WHERE (music.title LIKE :searchQuery OR music.genre LIKE :searchQuery) AND  owner_account_id = :creatorCondition AND genre = :genreCondition ORDER BY '.$order.' '.$direction.' LIMIT :limit OFFSET :offset';
                $params = [
                    'searchQuery' => '%'.$searchQuery.'%',
                    'creatorCondition' => $creatorCondition,
                    'genreCondition' => $genreCondition,
                    'limit' => $limit,
                    'offset' => ($currentPage-1)*$limit,
                ];
            }

            if ($queryParams['genre'] == 'all' && $queryParams['creator'] == 'all') {
                $query = 'SELECT *, username FROM music INNER JOIN account ON music.owner_account_id = account.account_id WHERE (music.title LIKE :searchQuery OR music.genre LIKE :searchQuery) ORDER BY '.$order.' '.$direction.' LIMIT :limit OFFSET :offset';
                $params = [
                    'searchQuery' => '%'.$searchQuery.'%',
                    'limit' => $limit,
                    'offset' => ($currentPage-1)*$limit,
                ];
            }

            $musicRes = execSelect($query, $params);

            // Get the image src for each album
            foreach ($musicRes as &$music) {
                $music['album_name'] = execSelect('SELECT name FROM album WHERE album_id = :album_id', ['album_id' => $music['album_id']])[0]['name'];
                $music['album_cover_filename'] = getAlbumImageByID($music['album_id']);
            }

            $res = [
                'musics' => $musicRes,
            ];

            header('Content-Type: application/json');
            http_response_code(200);
            echo json_encode($res);
            exit;

            break;
        default:
            http_response_code(401);
            exit;
    }
} catch (Exception $e) {
    http_response_code($e->getCode());
    exit;
}
