const searchInput = document.querySelector(".input-search");
const filterInput = document.querySelector("#filter");
const sortInput = document.querySelector("#sort");

const prevButton = document.querySelector("#previous");
const nextButton = document.querySelector("#next");
const buttonSearch = document.querySelector(".search");
const pageNumber = document.querySelector("#page-number");

const pageText = document.querySelector("#pagination-text");
const usersResult = document.querySelector(".user-list");
const pagination = document.querySelector(".pagination");

let currentPage = 1;

const debounce = (func, delay) => {
    let timer;
    return (...args) => {
        clearTimeout(timer);
        timer = setTimeout(() => {
            func.apply(this, args);
        }, delay);
    };
};


prevButton &&
    prevButton.addEventListener("click", async () => {
        if (currentPage === 1) {
            return;
        }
        currentPage -= 1;
        const xhr = new XMLHttpRequest();
        xhr.open(
            "GET",
            `/public/song/fetch/${currentPage}?csrf_token=${CSRF_TOKEN}&q=${searchInput.value}&filter=${filterInput.value}&sort=${sortInput.value}`
        );

        xhr.send();

        xhr.onreadystatechange = function () {
            if (this.readyState === XMLHttpRequest.DONE) {
                data = JSON.parse(this.responseText);
                updateData(data);
            }
        };
    });

nextButton &&
    nextButton.addEventListener("click", async () => {
        if (currentPage === PAGES) {
            return;
        }
        currentPage += 1;
        const xhr = new XMLHttpRequest();
        xhr.open(
            "GET",
            `/public/song/fetch/${currentPage}?csrf_token=${CSRF_TOKEN}&q=${searchInput.value}&filter=${filterInput.value}&sort=${sortInput.value}`
        );

        xhr.send();

        xhr.onreadystatechange = function () {
            if (this.readyState === XMLHttpRequest.DONE) {
                data = JSON.parse(this.responseText);
                updateData(data);
            }
        };
    });

searchInput &&
    searchInput.addEventListener("keyup", 
        debounce(
            async (e) => {
                currentPage = 1;
                e.preventDefault();
                window.history.pushState(
                    "",
                    "",
                    `/users?q=${searchInput.value}`
                );
                const xhr = new XMLHttpRequest();
                xhr.open(
                    "GET",
                    `/users/fetch/?csrf_token=${CSRF_TOKEN}&q=${searchInput.value}`
                );

                xhr.send();

                xhr.onreadystatechange = function () {
                    if (this.readyState === XMLHttpRequest.DONE) {
                        data = JSON.parse(this.responseText);
                        console.log(data);
                        updateData(data);
                    }
                };
               
            },
            500
        ));

buttonSearch &&
    buttonSearch.addEventListener("submit", async (e) => {
        currentPage = 1;
        e.preventDefault();
        window.history.pushState(
            "",
            "",
            `/users?q=${searchInput.value}`
        );
        const xhr = new XMLHttpRequest();
        xhr.open(
            "GET",
            `/users/fetch/?csrf_token=${CSRF_TOKEN}&q=${searchInput.value}`
        );

        xhr.send();

        xhr.onreadystatechange = function () {
            if (this.readyState === XMLHttpRequest.DONE) {
                data = JSON.parse(this.responseText);
                console.log(data);
                updateData(data);
            }
        };
    });

const updateData = (data) => {
    let newHTML = "";
    data.map((user) => {
        newHTML += `
        <div class="user">
            <div>Username       : ${user.username}</div>
            <div>Admin              : ${user.is_admin ? 'Yes' : 'No'}</div>
            <div>Account ID      : ${user.account_id}</div>
        </div>
        `;
    });
    usersResult.innerHTML = newHTML;
    pageNumber.innerHTML = currentPage;
    if (currentPage == 1) {
        prevButton.disabled = true;
    } else {
        prevButton.disabled = false;
    }

    if (currentPage == PAGES) {
        nextButton.disabled = true;
    } else {
        nextButton.disabled = false;
    }
};

const newData = (data) => {
    pages = data.pages;
    let newHTML = "";
    if (pages === 0) {
        newHTML += `
        <p class="no-result">
            Your search did not match any songs in our database!
        </p>
        `;
        usersResult.innerHTML = newHTML;
        pageText.innerHTML = `Page <span id="page-number">0</span> out of 0 pages`;
        prevButton.disabled = true;
        nextButton.disabled = true;
        pagination.style.display = "none";
    } else {
        pagination.style.display = "block";
        currentPage = 1;
        pageText.innerHTML = `Page <span id="page-number">1</span> out of ${data.pages} pages`;
        updateData(data);
    }
};
