<?php

global $is_admin;
require_once 'util/album-finder.php';
require_once 'util/account-finder.php';

$name = "";
$artist = "";
$year = "";

function populateFields($id): void {
    global $name, $artist, $year;

    $result = execSelect("SELECT * FROM album WHERE album_id = :id", ['id' => $id]);

    if (count($result) == 0) {
        return;
    }

    $name = $result[0]['name'];
    $artist = getAccountName($result[0]['owner_account_id']);
    $year = $result[0]['year'];
}

$id = $_GET['id'] ?? null;
if (is_numeric($id)) {
    populateFields($id);
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title><?php echo $artist . ' - ' . $name ?></title>
    <script src="/presentation/music/info/js/albumInfo.js" defer></script>
    <link rel="stylesheet" href="/presentation/music/info/css/albumInfo.css">
    <link rel="stylesheet" type="text/css" href="/presentation/template/css/sidebar.css">
    <link rel="stylesheet" type="text/css" href="/presentation/template/css/navbar.css">
    <link rel="preconnect" href="https://fonts.googleapis.com%22%3E/">
    <link rel="preconnect" href="https://fonts.gstatic.com/" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500&display=swap" rel="stylesheet">
</head>
<body>
<div class="wrapper">
    <?php require 'presentation/template/sidebar.php' ?>
    <div class="main-wrapper">
        <?php require 'presentation/template/navbar.php' ?>
        <div class="img-container">
            <img src="<?php echo getAlbumImage() ?>" alt="Album">
        </div>
        <?php if ($is_admin) {?>
            <div id="edit-b">
                <button id="edit-button">Edit</button>
            </div>
            <style>
                .img-container {
                    margin-bottom: 10px !important;
                }

                #edit-b {
                    display: flex;
                    justify-content: center;
                }

                #edit-button {
                    width: 100px;
                    height: 30px;
                    border: none;
                    border-radius: 5px;
                    background-color: #da0f47;
                    color: white;
                    font-size: 15px;
                    font-weight: 500;
                    cursor: pointer;
                }
            </style>
            <script>
                document.getElementById("edit-button").addEventListener("click", () => {
                    window.location.href = "/album/edit?id=<?php echo $id ?>";
                });
            </script>
        <?php } ?>
        <div id="album-info">
            <p id="artist-title"><?php echo $artist.' - '.$name ?></p>
            <div class="more-info">
                <p id="year"><?php echo $year ?></p>
            </div>
        </div>
        <div id="music-list-d">
            <ol id="music-list">
                <?php
                populateList($id);
                ?>
            </ol>
        </div>
        <div id="audio-d">
            <audio id="audio" controls hidden="hidden">
                <source src="" type="audio/mp3">
            </audio>
        </div>
    </div>
</div>
</body>
</html>