<?php

require_once 'util/account-finder.php';
require_once 'util/album-finder.php';

$title = 'Title';
$artist = 'Artist';
$album = 'Album';
$genre = 'Genre';
$year = 'Year';
$album_id = null;

function populateFields($id): void {
    global $title, $artist, $album, $genre, $year, $album_id;

    $result = execSelect("SELECT * FROM music WHERE music_id = :id", ['id' => $id]);

    if (count($result) == 0) {
        return;
    }

    $title = $result[0]['title'];
    $artist = getAccountName($result[0]['owner_account_id']);
    $album = getAlbumName($result[0]['album_id']);
    $genre = $result[0]['genre'] ?? 'Unknown';
    $year = $result[0]['year'] ?? 'Unknown';
    $album_id = $result[0]['album_id'];
}

$id = $_GET['id'] ?? null;
if (is_numeric($id)) {
    populateFields($id);
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title><?php echo $artist . ' - ' . $title ?></title>
    <script src="/presentation/music/info/js/musicInfo.js" defer></script>
    <link rel="stylesheet" href="/presentation/music/info/css/musicInfo.css">
    <link rel="stylesheet" type="text/css" href="/presentation/template/css/sidebar.css">
    <link rel="stylesheet" type="text/css" href="/presentation/template/css/navbar.css">
    <link rel="preconnect" href="https://fonts.googleapis.com%22%3E/">
    <link rel="preconnect" href="https://fonts.gstatic.com/" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500&display=swap" rel="stylesheet">
</head>
<body>
<div class="wrapper">
    <?php require 'presentation/template/sidebar.php' ?>
    <div class="main-wrapper">
        <?php require 'presentation/template/navbar.php' ?>
        <div class="img-container">
            <img src="<?php echo getAlbumImageFromMusic() ?>" alt="Album">
        </div>
        <div id="music-info">
            <p id="artist-title"><?php echo $artist.' - '.$title ?></p>
            <a href="<?php echo '/album?id='.$album_id ?>" id="album"><?php echo $album ?></a>
            <div id="more-info-container">
                <div class="more-info">
                    <p id="genre"><?php echo $genre ?></p>
                </div>
                <div class="more-info" id="dot-d">
                    <p id="dot">&#x2022</p>
                </div>
                <div class="more-info">
                    <p id="year"><?php echo $year ?></p>
                </div>
            </div>
            <div id="play-d">
                <button id="play-b">Play</button>
            </div>
            <div id="lyrics-d">
                <a href="#" id="lyrics">Lyrics</a>
            </div>
            <div id="lyrics-b">
                <label for="lyrics-box"></label><textarea wrap="hard" cols="450" rows="6" maxlength="5000" id="lyrics-box" hidden="hidden" disabled readonly></textarea>
            </div>
        </div>
        <div id="audio-d">
            <audio id="audio" controls hidden="hidden">
                <source src="" type="audio/mp3">
            </audio>
        </div>
    </div>
</div>
</body>
</html>