const searchInput = document.querySelector(".input-search");
const buttonSearch = document.querySelector(".search");
const songsResult = document.querySelector(".music-wrapper");
const pagination = document.querySelector(".pagination");
const prevButton = document.querySelector("#prev-page");
const nextButton = document.querySelector("#next-page");
const musics = document.querySelectorAll(".music");

// Sorting
const sortInput = document.querySelector(".sort-select");
const orderInput = document.querySelector(".order-select");
const genreInput = document.querySelector(".genre-select");
const creatorInput = document.querySelector(".creator-select");

const debounce = (func, delay) => {
    let timer;
    return (...args) => {
        clearTimeout(timer);
        timer = setTimeout(() => {
            func.apply(this, args);
        }, delay);
    };
};

let currentPage = 1;

prevButton &&
    prevButton.addEventListener("click", async () => {
        if (currentPage === 1) {
            return;
        }
        currentPage -= 1;
        const xhr = new XMLHttpRequest();
        xhr.open(
            "GET",
            `/album/fetch/?p=${currentPage}&l=${LIMIT}&csrf_token=${CSRF_TOKEN}&q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&genre=${genreInput.value}&creator=${creatorInput.value}`
        );

        xhr.send();

        xhr.onreadystatechange = function () {
            if (this.readyState === XMLHttpRequest.DONE) {
                data = JSON.parse(this.responseText);
                updateData(data);
            }
        };
    });

nextButton &&
    nextButton.addEventListener("click", async () => {
        if (currentPage === PAGES) {
            return;
        }
        currentPage += 1;
        const xhr = new XMLHttpRequest();
        xhr.open(
            "GET",
            `/album/fetch/?p=${currentPage}&l=${LIMIT}&csrf_token=${CSRF_TOKEN}&q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&genre=${genreInput.value}&creator=${creatorInput.value}`
            );

        xhr.send();

        xhr.onreadystatechange = function () {
            if (this.readyState === XMLHttpRequest.DONE) {
                data = JSON.parse(this.responseText);
                updateData(data);
            }
        };
    });

searchInput &&
searchInput.addEventListener("keyup", 
    debounce(
        (e) => {
            currentPage = 1;
            e.preventDefault();
            window.history.pushState(
                "",
                "",
                `/music-list?q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&genre=${genreInput.value}&creator=${creatorInput.value}`
            );
            const xhr = new XMLHttpRequest();
            xhr.open(
                "GET",
                `/music/fetch/?p=${currentPage}&l=${LIMIT}&csrf_token=${CSRF_TOKEN}&q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&genre=${genreInput.value}&creator=${creatorInput.value}`
            );

            xhr.send();

            xhr.onreadystatechange = function () {
                if (this.readyState === XMLHttpRequest.DONE) {
                    data = JSON.parse(this.responseText);
                    console.log(data);
                    updateData(data);
                }
            };
            
        },
        500
    ));
 

buttonSearch &&
    buttonSearch.addEventListener("submit",  (e) => {
        currentPage = 1;
        e.preventDefault();
        window.history.pushState(
            "",
            "",
            `/music-list?q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&genre=${genreInput.value}&creator=${creatorInput.value}`
        );
        const xhr = new XMLHttpRequest();
        xhr.open(
            "GET",
            `/music/fetch/?p=${currentPage}&l=${LIMIT}&csrf_token=${CSRF_TOKEN}&q=${searchInput.value}&sort=${sortInput.value}&order=${orderInput.value}&genre=${genreInput.value}&creator=${creatorInput.value}`
        );

        xhr.send();

        xhr.onreadystatechange = function () {
            if (this.readyState === XMLHttpRequest.DONE) {
                data = JSON.parse(this.responseText);
                updateData(data);
            }
        };
    });

const updateData = (data) => {
    let newHTML = "";
    data.musics.map((music) => {
        newHTML += `
        <div class="music" id=${music.album_id} >
            <img src="${music.album_cover_filename}" alt="${music.title}_cover">
            <h3>${music.title}</h3>
            <h5>${music.album_name}</h5>
            <p>By : ${music.username}</p>
            <p>Released : ${music.year}</p>
            <p>ID : ${music.music_id}</p>
        </div>
        `;
    });
    songsResult.innerHTML = newHTML;
    songsResult.addEventListener("click", function (e) {
        const clickedElement = e.target;
        const musicElement = clickedElement.closest(".music");
        if (musicElement) {
            const musicId = musicElement.id;
            // Redirect 
            window.location.href = `/music?id=${musicId}`;
        }
    });
    
    pageNumber.innerHTML = currentPage;
    if (currentPage == 1) {
        prevButton.disabled = true;
    } else {
        prevButton.disabled = false;
    }

    if (currentPage == PAGES) {
        nextButton.disabled = true;
    } else {
        nextButton.disabled = false;
    }
};



musics.forEach((music) => {
    music.addEventListener("click", async (e) => {
        e.preventDefault();

        // Redirect to music page
        window.location.href = `/music?id=${music.id}`;
    });
});

